
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
#error "Only <gtk/gtk.h> can be included directly."
#endif

#include <glib-object.h>
#include <gdk/version/gdkversionmacros.h>

G_BEGIN_DECLS

/* enumerations from "gtksvg.h" */
GDK_AVAILABLE_IN_ALL GType gtk_svg_features_get_type (void) G_GNUC_CONST;
#define GTK_TYPE_SVG_FEATURES (gtk_svg_features_get_type ())
GDK_AVAILABLE_IN_ALL GType gtk_svg_error_get_type (void) G_GNUC_CONST;
#define GTK_TYPE_SVG_ERROR (gtk_svg_error_get_type ())
G_END_DECLS

/* Generated data ends here */

