
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __GSK_ENUM_TYPES_H__
#define __GSK_ENUM_TYPES_H__

#include <gdk/gdk.h>

G_BEGIN_DECLS

/* enumerations from "gskenums.h" */
GDK_AVAILABLE_IN_ALL GType gsk_render_node_type_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_RENDER_NODE_TYPE (gsk_render_node_type_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_scaling_filter_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_SCALING_FILTER (gsk_scaling_filter_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_blend_mode_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_BLEND_MODE (gsk_blend_mode_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_porter_duff_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_PORTER_DUFF (gsk_porter_duff_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_corner_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_CORNER (gsk_corner_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_side_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_SIDE (gsk_side_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_fill_rule_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_FILL_RULE (gsk_fill_rule_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_isolation_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_ISOLATION (gsk_isolation_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_line_cap_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_LINE_CAP (gsk_line_cap_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_line_join_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_LINE_JOIN (gsk_line_join_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_path_operation_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_PATH_OPERATION (gsk_path_operation_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_path_direction_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_PATH_DIRECTION (gsk_path_direction_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_serialization_error_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_SERIALIZATION_ERROR (gsk_serialization_error_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_transform_category_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_TRANSFORM_CATEGORY (gsk_transform_category_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_gl_uniform_type_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_GL_UNIFORM_TYPE (gsk_gl_uniform_type_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_mask_mode_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_MASK_MODE (gsk_mask_mode_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_snap_direction_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_SNAP_DIRECTION (gsk_snap_direction_get_type ())

/* enumerations from "gskpath.h" */
GDK_AVAILABLE_IN_ALL GType gsk_path_foreach_flags_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_PATH_FOREACH_FLAGS (gsk_path_foreach_flags_get_type ())
GDK_AVAILABLE_IN_ALL GType gsk_path_intersection_get_type (void) G_GNUC_CONST;
#define GSK_TYPE_PATH_INTERSECTION (gsk_path_intersection_get_type ())
G_END_DECLS

#endif /* __GSK_ENUM_TYPES_H__ */

/* Generated data ends here */

